@@ -24,7 +24,7 @@
 #include "players/player.h"
 #include "planet.h"
 #include <KLocalizedString>
-#include <KDebug>
+#include <QDebug>
 #include <cmath>
 
 KRandomSequence Game::random = KRandomSequence();
@@ -37,10 +37,10 @@ Game::Game(QObject *parent) :
     m_map = new Map(10, 10);
     m_gameMachine.addState(m_finalState);
     m_neutral = new NeutralPlayer(this);
-    connect(&m_gameMachine, SIGNAL(finished()), this, SIGNAL(finished()));
+    connect(&m_gameMachine, &QStateMachine::finished, this, &Game::finished);
 }
 
-QList<Planet*> Game::planets()
+const QList<Planet*> Game::planets()
 {
     return m_map->planets();
 }
@@ -67,7 +67,7 @@ int Game::generatePlanetProduction()
     return 5 + random.getLong(10);
 }
 
-bool Game::attack(Planet *sourcePlanet, Planet *destPlanet, int shipCount, bool standingOrder)
+bool Game::attack(Planet *sourcePlanet, Planet *destPlanet, long long shipCount, bool standingOrder)
 {
     int arrival = int(std::ceil(m_map->distance(sourcePlanet, destPlanet))) + m_turnCounter;
     if(standingOrder)
@@ -176,27 +176,27 @@ void Game::makeKill(Fleet *fleet, Player *player)
 
 void Game::findWinner()
 {
-    kDebug() << "Searching for survivors";
+    //qDebug() << "Searching for survivors";
     // Check for survivors
     Player *winner = 0;
-    foreach (Player *player, m_players) {
+    for (Player *player : players()) {
         if (player->isNeutral() || player->isSpectator()) {
             continue;
         }
         if (!player->isDead()) {
             if (winner) {
-                kDebug() << "Ok, returning 0";
+                //qDebug() << "Ok, returning 0";
                 return;
             } else {
                 winner = player;
             }
         }
     }
-    kDebug() << "Ok, returning " << winner;
+    //qDebug() << "Ok, returning " << winner;
     if (winner)
     {
         // We got a winner
-        kDebug() << "Trying to stop";
+        //qDebug() << "Trying to stop";
         this->stop();
         emit(finished());
     }
