@@ -34,21 +34,15 @@
 
 class NeutralPlayer : public Player
 {
-    Q_OBJECT
 public:
     explicit NeutralPlayer(Game *game);
 
-    virtual bool isDead();
+    bool isDead() override;
 
-    virtual bool isNeutral();
+    bool isNeutral() override;
 
 protected:
-    virtual void play();
-
-signals:
-
-public slots:
-
+    void play() override;
 };
 
 #endif // NEUTRALPLAYER_H
